import sys

valhalla_of_python = """
El Valhalla de Python, por un grupo de chiefs, officers, gurús y ninjas de Python.

1. Si no se entiende a primera vista ... vas por buen camino.
2. El código simple... nunca fue tendencia.
3. Lo que es bonito... está sobrevalorado.
4. Si puedes evitarlo... publícalo de todos modos.
5. Lo práctico es aburrido; lo caótico es interesante.
6. Las excepciones no existen... solo son nuevos comienzos.
7. Si no puedes hacerlo bien... hazlo mal.
8. Si no puedes hacerlo mal... no lo hagas.
9. Si no puedes hacerlo... no lo intentes.
10. Si no puedes... no lo intentes.
11. Si no... no.
12. Si... no.
13. ...
"""


def print_valhalla():
    """Imprime el Valhalla de Python."""
    sys.stdout.write(valhalla_of_python + "\n")


print_valhalla()
